
Overview
========

ChaosMagPy is a simple Python package for evaluating the CHAOS geomagnetic
field model and other models of Earth's magnetic field. The latest CHAOS model
is available at http://www.spacecenter.dk/files/magnetic-models/CHAOS-7/. To
quickly get started, download the complete working example including the latest
model under the "Forward code" section.

Documentation
-------------

The documentation of the current release is available on Read the Docs
(https://chaosmagpy.readthedocs.io/en/)

|pypi| |docs| |doi| |license|

.. |pypi| image:: https://badge.fury.io/py/chaosmagpy.svg
   :target: https://badge.fury.io/py/chaosmagpy/

.. |docs| image:: https://readthedocs.org/projects/chaosmagpy/badge/
   :target: https://chaosmagpy.readthedocs.io/en/
   :alt: Documentation Status

.. |license| image:: https://img.shields.io/badge/License-MIT-blue.svg
   :target: license.html

.. |doi| image:: https://zenodo.org/badge/DOI/10.5281/zenodo.3352398.svg
   :target: https://doi.org/10.5281/zenodo.3352398
